==> crow-2.15.0.tar.bz2: crow-2.15.0/crow/views1.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef CROW_VIEWS1_H
#define CROW_VIEWS1_H

#include "views.h"

namespace Crow {

typedef TChildView<RowChild> RowChildView;

class GtkBinView : public TGtkContainerView<BinContainer> {

public:
	GtkBinView();

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);

};

class GtkAlignmentView : public GtkBinView, public TCreateInstance<Gtk::Alignment> {

public:
	GtkAlignmentView();

};

class GtkFrameView : public GtkBinView, public TCreateInstance<Gtk::Frame> {

public:
	using TCreateInstance<Gtk::Frame>::getObject;

	GtkFrameView();

protected:
	void setLabelWidgetSet(Property * property, Any value);
	Any getLabel(Property * property);
	void setLabel(Property * property, Any value);
	void configureLabelWidget(Property * property, PEntityView ev);

};

class GtkAspectFrameView : public GtkFrameView {

public:
	GtkAspectFrameView();

protected:
	Any createInstance();

};

class GtkExpanderView : public GtkBinView, public TCreateInstance<Gtk::Expander> {

public:
	using TCreateInstance<Gtk::Expander>::getObject;

	GtkExpanderView();

protected:
	void initInstance();
	void initDesign();
	bool isTopChild(PChild child);
	bool isActiveWidget(Gtk::Widget * widget);
	void setLabelWidgetSet(Property * property, Any value);
	Any getLabel(Property * property);
	void setLabel(Property * property, Any value);
	void configureLabelWidget(Property * property, PEntityView ev);
	void setExpanded(Property * property, Any value);

};

class GtkScrolledWindowView : public GtkBinView, public TCreateInstance<Gtk::ScrolledWindow> {

public:
	using TCreateInstance<Gtk::ScrolledWindow>::getObject;

	GtkScrolledWindowView();

protected:
	ScrolledWindowContainer * createContainer();
	Rectangle getChildArea();
	void configureAdjustment(Property * property, PEntityView view);
	void setWindowPlacementSet(Property * property, Any value);
	Any getAutoViewport(Property * property);

};

class GtkHandleBoxView : public GtkBinView, public TCreateInstance<Gtk::HandleBox> {

public:
	using TCreateInstance<Gtk::HandleBox>::getObject;

	GtkHandleBoxView();

protected:
	void initInstance();
	void setSnapEdgeSet(Property * property, Any value);

};

class GtkViewportView : public GtkBinView {

public:
	GtkViewportView();

protected:
	Any createInstance();

};

class BoxChildView : public TChildView<BoxChild> {

public:
	BoxChildView();

protected:
	Any getPack(Property * property);
	void setPack(Property * property, Any value);
	Any getOptions(Property * property);
	void setOptions(Property * property, Any value);
	Any getPadding(Property * property);
	void setPadding(Property * property, Any value);

};

class GtkBoxView : public TGtkContainerView<BoxContainer> {

public:
	GtkBoxView();
	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setCapacityProperty(Property * property, Any value);
	void setCapacity(int * capS, int * capE);
	void onAsContainerSetup();

};

class GtkHBoxView : public GtkBoxView, public TCreateInstance<Gtk::HBox> {
};

class GtkVBoxView : public GtkBoxView, public TCreateInstance<Gtk::VBox> {
};

class ButtonBoxChildView : public BoxChildView {

public:
	using GlibObjectView::getObject;

	ButtonBoxChildView();

protected:
	Any createInstance();
	Any getSecondary(Property * property);
	void setSecondary(Property * property, Any value);

};

class GtkButtonBoxView : public GtkBoxView {

public:
	using GlibObjectView::getObject;

	GtkButtonBoxView();

protected:
	void initInstance();
	ButtonBoxContainer * createContainer();

};

class GtkHButtonBoxView : public GtkButtonBoxView, public TCreateInstance<Gtk::HButtonBox> {
};

class GtkVButtonBoxView : public GtkButtonBoxView, public TCreateInstance<Gtk::VButtonBox> {
};

class PanedChildView : public TChildView<PanedChild> {

public:
	PanedChildView();

protected:
	Any getResize(Property * property);
	void setResize(Property * property, Any value);
	Any getShrink(Property * property);
	void setShrink(Property * property, Any value);

};

class GtkPanedView : public TGtkContainerView<PanedContainer> {

public:
	GtkPanedView();
	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setPositionSet(Property * property, Any value);

};

class GtkHPanedView : public GtkPanedView, public TCreateInstance<Gtk::HPaned> {
};

class GtkVPanedView : public GtkPanedView, public TCreateInstance<Gtk::VPaned> {
};

class NotebookChildView : public TChildView<NotebookChild> {

public:
	NotebookChildView();

protected:
	Any getTabLabel(Property * property);
	void setTabLabel(Property * property, Any value);
	Any getTabLabelWidget(Property * property);
	void setTabLabelWidget(Property * property, Any value);
	Any getMenuLabel(Property * property);
	void setMenuLabel(Property * property, Any value);
	Any getMenuLabelWidget(Property * property);
	void setMenuLabelWidget(Property * property, Any value);
	Any getPackOptions(Property * property);
	void setPackOptions(Property * property, Any value);

};

class GtkNotebookView : public TGtkContainerView<NotebookContainer>, public TCreateInstance<Gtk::Notebook> {

public:
	using TCreateInstance<Gtk::Notebook>::getObject;

	GtkNotebookView();
	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setCapacityProperty(Property * property, Any value);
	void setCapacity(int * capacity);
	bool isTopChild(PChild child);
	bool isActiveWidget(Gtk::Widget * widget);
	void onAsContainerSetup();

};

class TableChildView : public TChildView<TableChild> {

public:
	TableChildView();

protected:
	Any getCell(Property * property);
	void setCell(Property * property, Any value);
	Any getCellSpan(Property * property);
	void setCellSpan(Property * property, Any value);
	Any getPaddingX(Property * property);
	void setPaddingX(Property * property, Any value);
	Any getPaddingY(Property * property);
	void setPaddingY(Property * property, Any value);
	Any getXExpand(Property * property);
	void setXExpand(Property * property, Any value);
	Any getXFill(Property * property);
	void setXFill(Property * property, Any value);
	Any getXShrink(Property * property);
	void setXShrink(Property * property, Any value);
	Any getYExpand(Property * property);
	void setYExpand(Property * property, Any value);
	Any getYFill(Property * property);
	void setYFill(Property * property, Any value);
	Any getYShrink(Property * property);
	void setYShrink(Property * property, Any value);

};

class GtkTableView : public TGtkContainerView<TableContainer> {

public:
	GtkTableView();
	PNode createChild(const Place & place, PNode widget);

protected:
	Any createInstance();
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setCapacityProperty(Property * property, Any value);
	void setCapacity(int * capX, int * capY);
	void onAsContainerSetup();

};

class XYChildView : public TChildView<XYChild> {

public:
	XYChildView();

protected:
	Any getXY(Property * property);
	void setXY(Property * property, Any value);

};

class XYContainerView : public virtual GtkContainerView {

public:
	XYContainerView();

	bool findFreePlace(const Point & p, FreePlace * fplace);
	FreePlaces findFreePlaces(const Point & p, const Nodes & nodes, const Point & p0);
	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	virtual PGdkWindow getExposeWindow();
	Point getWidgetPreferredSize(PNode widget);
	bool onExposeEvent(GdkEventExpose * event);
	void onAsContainerSetup();

private:
	sigc::connection expcon;

};

class GtkAdjustmentView : public GlibObjectView {

public:
	GtkAdjustmentView();
	void configureForScrolling();

protected:
	void setRangeProperty(Property * property, Any value);

};

}

#endif

==> crow-2.17.1.tar.bz2: crow-2.17.1/crow/views1.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef CROW_VIEWS1_H
#define CROW_VIEWS1_H

#include "views.h"

namespace Crow {

typedef TChildView<RowChild> RowChildView;

class GtkBinView : public TGtkContainerView<BinContainer> {

public:
	GtkBinView();

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);

};

class GtkAlignmentView : public GtkBinView, public TCreateInstance<Gtk::Alignment> {

public:
	GtkAlignmentView();

};

class GtkFrameView : public GtkBinView, public TCreateInstance<Gtk::Frame> {

public:
	using TCreateInstance<Gtk::Frame>::getObject;

	GtkFrameView();

protected:
	void setLabelWidgetSet(Property * property, Any value);
	Any getLabel(Property * property);
	void setLabel(Property * property, Any value);
	void configureLabelWidget(Property * property, PEntityView ev);

};

class GtkAspectFrameView : public GtkFrameView {

public:
	GtkAspectFrameView();

protected:
	Any createInstance();

};

class GtkExpanderView : public GtkBinView, public TCreateInstance<Gtk::Expander> {

public:
	using TCreateInstance<Gtk::Expander>::getObject;

	GtkExpanderView();

protected:
	void initInstance();
	void initDesign();
	bool isTopChild(PChild child);
	bool isActiveWidget(Gtk::Widget * widget);
	void setLabelWidgetSet(Property * property, Any value);
	Any getLabel(Property * property);
	void setLabel(Property * property, Any value);
	void configureLabelWidget(Property * property, PEntityView ev);
	void setExpanded(Property * property, Any value);

};

class GtkScrolledWindowView : public GtkBinView, public TCreateInstance<Gtk::ScrolledWindow> {

public:
	using TCreateInstance<Gtk::ScrolledWindow>::getObject;

	GtkScrolledWindowView();

	Slider getSlider(Manipulator manip);
	void setSlider(Manipulator manip, double value);

protected:
	ScrolledWindowContainer * createContainer();
	Rectangle getChildArea();
	void configureAdjustment(Property * property, PEntityView view);
	void setWindowPlacementSet(Property * property, Any value);
	Any getAutoViewport(Property * property);

};

class GtkHandleBoxView : public GtkBinView, public TCreateInstance<Gtk::HandleBox> {

public:
	using TCreateInstance<Gtk::HandleBox>::getObject;

	GtkHandleBoxView();

protected:
	void initInstance();
	void setSnapEdgeSet(Property * property, Any value);

};

class GtkViewportView : public GtkBinView {

public:
	GtkViewportView();

protected:
	Any createInstance();

};

class BoxChildView : public TChildView<BoxChild> {

public:
	BoxChildView();

protected:
	Any getPack(Property * property);
	void setPack(Property * property, Any value);
	Any getOptions(Property * property);
	void setOptions(Property * property, Any value);
	Any getPadding(Property * property);
	void setPadding(Property * property, Any value);

};

class GtkBoxView : public TGtkContainerView<BoxContainer> {

public:
	GtkBoxView();
	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setCapacityProperty(Property * property, Any value);
	void setCapacity(int * capS, int * capE);
	void onAsContainerSetup();

};

class GtkHBoxView : public GtkBoxView, public TCreateInstance<Gtk::HBox> {
};

class GtkVBoxView : public GtkBoxView, public TCreateInstance<Gtk::VBox> {
};

class ButtonBoxChildView : public BoxChildView {

public:
	using GlibObjectView::getObject;

	ButtonBoxChildView();

protected:
	Any createInstance();
	Any getSecondary(Property * property);
	void setSecondary(Property * property, Any value);

};

class GtkButtonBoxView : public GtkBoxView {

public:
	using GlibObjectView::getObject;

	GtkButtonBoxView();

protected:
	void initInstance();
	ButtonBoxContainer * createContainer();

};

class GtkHButtonBoxView : public GtkButtonBoxView, public TCreateInstance<Gtk::HButtonBox> {
};

class GtkVButtonBoxView : public GtkButtonBoxView, public TCreateInstance<Gtk::VButtonBox> {
};

class PanedChildView : public TChildView<PanedChild> {

public:
	PanedChildView();

protected:
	Any getResize(Property * property);
	void setResize(Property * property, Any value);
	Any getShrink(Property * property);
	void setShrink(Property * property, Any value);

};

class GtkPanedView : public TGtkContainerView<PanedContainer> {

public:
	using GlibObjectView::getObject;

	GtkPanedView();
	PNode createChild(const Place & place, PNode widget);

	Slider getSlider(Manipulator manip);
	void setSlider(Manipulator manip, double value);

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setPositionSet(Property * property, Any value);

};

class GtkHPanedView : public GtkPanedView, public TCreateInstance<Gtk::HPaned> {
};

class GtkVPanedView : public GtkPanedView, public TCreateInstance<Gtk::VPaned> {
};

class PagesViewBase : public virtual GtkContainerView {

public:
	PagesViewBase();

	Slider getSlider(Manipulator manip);
	void setSlider(Manipulator manip, double value);

	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setCapacityProperty(Property * property, Any value);
	void setCapacity(int * capacity);
	void onAsContainerSetup();

	virtual PagesContainer * getPagesContainer() = 0;
	virtual bool appropManip(Manipulator manip) = 0;

};

class NotebookChildView : public TChildView<NotebookChild> {

public:
	NotebookChildView();

protected:
	Any getTabLabel(Property * property);
	void setTabLabel(Property * property, Any value);
	Any getTabLabelWidget(Property * property);
	void setTabLabelWidget(Property * property, Any value);
	Any getMenuLabel(Property * property);
	void setMenuLabel(Property * property, Any value);
	Any getMenuLabelWidget(Property * property);
	void setMenuLabelWidget(Property * property, Any value);
	Any getPackOptions(Property * property);
	void setPackOptions(Property * property, Any value);

};

class GtkNotebookView : public PagesViewBase, public TGtkContainerView<NotebookContainer>, public TCreateInstance<Gtk::Notebook> {

public:
	using TCreateInstance<Gtk::Notebook>::getObject;

	GtkNotebookView();

protected:
	bool isTopChild(PChild child);
	bool isActiveWidget(Gtk::Widget * widget);

	PagesContainer * getPagesContainer() { return getContainer(); }
	bool appropManip(Manipulator manip);

};

class AssistantChildView : public TChildView<AssistantChild> {

public:
	AssistantChildView();

protected:
	Any getPageType(Property * property);
	void setPageType(Property * property, Any value);
	Any getComplete(Property * property);
	void setComplete(Property * property, Any value);
	Any getTitle(Property * property);
	void setTitle(Property * property, Any value);
	Any getHeaderImage(Property * property);
	void setHeaderImage(Property * property, Any value);
	Any getSidebarImage(Property * property);
	void setSidebarImage(Property * property, Any value);

};

class GtkAssistantViewBase : public PagesViewBase, public TGtkContainerView<AssistantContainer>, public TCreateInstance<Gtk::Assistant> {

public:
	using TCreateInstance<Gtk::Assistant>::getObject;

	GtkAssistantViewBase();

	void revive() { ReviveGtkAssistant(GetPtr(getObject())); }

protected:
	bool isTopChild(PChild child);
	bool isActiveWidget(Gtk::Widget * widget);

	Any getPage(Property * property);
	void setPage(Property * property, Any value);

	PagesContainer * getPagesContainer() { return getContainer(); }
	bool appropManip(Manipulator manip);

};

class TableChildView : public TChildView<TableChild> {

public:
	TableChildView();

protected:
	Any getCell(Property * property);
	void setCell(Property * property, Any value);
	Any getCellSpan(Property * property);
	void setCellSpan(Property * property, Any value);
	Any getPaddingX(Property * property);
	void setPaddingX(Property * property, Any value);
	Any getPaddingY(Property * property);
	void setPaddingY(Property * property, Any value);
	Any getXExpand(Property * property);
	void setXExpand(Property * property, Any value);
	Any getXFill(Property * property);
	void setXFill(Property * property, Any value);
	Any getXShrink(Property * property);
	void setXShrink(Property * property, Any value);
	Any getYExpand(Property * property);
	void setYExpand(Property * property, Any value);
	Any getYFill(Property * property);
	void setYFill(Property * property, Any value);
	Any getYShrink(Property * property);
	void setYShrink(Property * property, Any value);

};

class GtkTableView : public TGtkContainerView<TableContainer> {

public:
	GtkTableView();
	PNode createChild(const Place & place, PNode widget);

protected:
	Any createInstance();
	void initDesign();
	void setupContainer();
	void setChildren(Property * property, Any value);
	void setCapacityProperty(Property * property, Any value);
	void setCapacity(int * capX, int * capY);
	void onAsContainerSetup();

};

class XYChildView : public TChildView<XYChild> {

public:
	XYChildView();

protected:
	Any getXY(Property * property);
	void setXY(Property * property, Any value);

};

class XYContainerView : public virtual GtkContainerView {

public:
	XYContainerView();

	bool findFreePlace(const Point & p, FreePlace * fplace);
	FreePlaces findFreePlaces(const Point & p, const Nodes & nodes, const Point & p0);
	PNode createChild(const Place & place, PNode widget);

protected:
	void initDesign();
	virtual PGdkWindow getExposeWindow();
	Point getWidgetPreferredSize(PNode widget);
	bool onExposeEvent(GdkEventExpose * event);
	void onAsContainerSetup();

private:
	sigc::connection expcon;

};

class GtkAdjustmentView : public GlibObjectView {

public:
	GtkAdjustmentView();
	void configureForScrolling();

protected:
	void setRangeProperty(Property * property, Any value);

};

}

#endif
